@@ -643,6 +643,15 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r.raise_for_status()
         return r.json()['id']
 
+    def execute_dataset_sync(self, dataset_slug):
+
+        dataset_id = self.get_dataset_by_slug(self._slug, dataset_slug)
+
+        dataset_url = self._base_url_askdata + '/smartdataset/datasets/' + dataset_id + '/sync'
+        r = requests.post(url=dataset_url, headers=self._headers)
+        r.raise_for_status()
+        return r
+
 
     def add_user_to_channel(self, channel_slug, user_email, role="FOLLOWER"):
 
