@@ -324,7 +324,9 @@ class Query:
                         operator = "<"
                 else:
                     operator = None
-                if where_condition.field.sourceDataType is not None:
+                if where_condition.field.internalDataType is not None:
+                    formatted_cond = where_condition.field.column + " (" + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
+                elif where_condition.field.sourceDataType is not None:
                     formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
                 else:
                     formatted_cond = where_condition.field.column + " " + operator + " " + formatted_value
